A pool represents a group of members over which the load balancing will be applied.

Algorithm: The load balancer algorithm that distributes traffic to the pool members.

- LEAST_CONNECTIONS: Allocates requests to the instance with the least number of active connections.
- ROUND_ROBIN: Rotates requests evenly between multiple instances.
- SOURCE_IP: Requests from a unique source IP address are consistently directed to the same instance.

Protocol: The protocol for which this pool and its members listen. A valid value is HTTP, HTTPS, PROXY, or TCP.

Session Persistence: The type of session persistence for distributing traffic to the pool members.

- SOURCE_IP: Session persistence based on source ip.
- HTTP_COOKIE: Session persistence based on http cookie.
- APP_COOKIE: Session persistence based on application cookie.